/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2011 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author:                                                              |
  +----------------------------------------------------------------------+
*/

/* $Id: header 310447 2011-04-23 21:14:10Z bjori $ */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_mysqlnd_to_stream.h"
#include "ext/mysqlnd/mysqlnd.h"

static int plugin_id;

/* {{{ proto resource mysqlnd_to_stream(mixed $connection)
   Gives access to the low-level stream used by aa MySQL connection */
PHP_FUNCTION(mysqlnd_to_stream)
{
	zval *conn_zv;
	MYSQLND *conn;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &conn_zv) == FAILURE) {
		return;
	}

	if (!(conn = zval_to_mysqlnd(conn_zv))) {
		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Passed variable is no mysqlnd based connection");
		RETURN_FALSE;
	}

	php_stream_to_zval(conn->net->stream, return_value);
}
/* }}} */

/* {{{ mysqlnd_to_stream_functions[]
 */
const zend_function_entry mysqlnd_to_stream_functions[] = {
	PHP_FE(mysqlnd_to_stream,	NULL)
	PHP_FE_END
};
/* }}} */

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(mysqlnd_to_stream)
{
	plugin_id = mysqlnd_plugin_register();
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(mysqlnd_to_stream)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "mysqlnd_to_stream support", "enabled");
	php_info_print_table_end();
}
/* }}} */

/* {{{ mysqlnd_to_stream_module_entry
 */
zend_module_entry mysqlnd_to_stream_module_entry = {
	STANDARD_MODULE_HEADER,
	"mysqlnd_to_stream",
	mysqlnd_to_stream_functions,
	PHP_MINIT(mysqlnd_to_stream),
	NULL,
	NULL,
	NULL,
	PHP_MINFO(mysqlnd_to_stream),
	"0.1",
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_MYSQLND_TO_STREAM
ZEND_GET_MODULE(mysqlnd_to_stream)
#endif

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
